@@ -1,13 +1,41 @@
 import os
 from unittest import TestCase
 
-from mock import patch
+import requests
 
-from pagerduty_api.base import Resource
-from pagerduty_api.exceptions import ConfigurationException
+from mock import patch, Mock
+
+from pagerduty_api.base import AuthorizedResource, Resource
+from pagerduty_api.exceptions import ConfigurationException, PagerDutyAPIServerException
 
 
 class ResourceTests(TestCase):
+    """
+    Tests for Resource
+    """
+
+    def setUp(self):
+        self.TEST_URL = 'https://www.google.com'
+
+    @patch.object(requests, 'post')
+    def test_post_not_ok(self, mock_post):
+        """
+        Test ._post() handles a not ok response
+        """
+        mock_response = Mock(name='response', ok=False, status_code=500, text='Server Error')
+        mock_post.return_value = mock_response
+
+        resource = Resource()
+
+        with self.assertRaises(PagerDutyAPIServerException):
+            resource._post(url=self.TEST_URL)
+
+        mock_post.assert_called_once_with(
+            url=self.TEST_URL,
+        )
+
+
+class AuthorizedResourceTests(TestCase):
 
     @patch.object(os.environ, 'get', spec_set=True)
     def test_resource_with_arg(self, os_environ_mock):
@@ -15,7 +43,7 @@ class ResourceTests(TestCase):
         Test the api_key gets set by an argument
         """
 
-        resource = Resource(api_key='123')
+        resource = AuthorizedResource(api_key='123')
 
         self.assertFalse(os_environ_mock.called)
 
@@ -28,7 +56,7 @@ class ResourceTests(TestCase):
         """
         os_environ_mock.return_value = '123'
 
-        resource = Resource()
+        resource = AuthorizedResource()
 
         os_environ_mock.assert_called_once_with('PAGERDUTY_API_KEY')
 
@@ -42,6 +70,6 @@ class ResourceTests(TestCase):
         os_environ_mock.return_value = None
 
         with self.assertRaises(ConfigurationException):
-            Resource()
+            AuthorizedResource()
 
         os_environ_mock.assert_called_once_with('PAGERDUTY_API_KEY')
